@@ -3,6 +3,6 @@ from slicemap.slicemap import SliceMap
 try:
     import matplotlib.pyplot as plt
 
-    from slicemap import plotting
+    from slicemap.plotting import plot_slicemap
 except ImportError:
     pass
